package com.sun.jmx.snmp.agent;

import java.util.Enumeration;
import com.sun.jmx.snmp.SnmpEngine;
import com.sun.jmx.snmp.SnmpPdu;
import com.sun.jmx.snmp.SnmpVarBind;
import java.util.Vector;

final class SnmpMibRequestImpl implements SnmpMibRequest
{
    private Vector<SnmpVarBind> varbinds;
    private int version;
    private Object data;
    private SnmpPdu reqPdu;
    private SnmpRequestTree tree;
    private SnmpEngine engine;
    private String principal;
    private int securityLevel;
    private int securityModel;
    private byte[] contextName;
    private byte[] accessContextName;
    
    public SnmpMibRequestImpl(SnmpEngine engine, SnmpPdu reqPdu, Vector<SnmpVarBind> varbinds, int version, Object data, String principal, int securityLevel, int securityModel, byte[] contextName, byte[] accessContextName) {
        this.reqPdu = null;
        this.tree = null;
        this.engine = null;
        this.principal = null;
        this.securityLevel = -1;
        this.securityModel = -1;
        this.contextName = null;
        this.accessContextName = null;
        this.varbinds = varbinds;
        this.version = version;
        this.data = data;
        this.reqPdu = reqPdu;
        this.engine = engine;
        this.principal = principal;
        this.securityLevel = securityLevel;
        this.securityModel = securityModel;
        this.contextName = contextName;
        this.accessContextName = accessContextName;
    }
    
    @Override
    public SnmpEngine getEngine() {
        return this.engine;
    }
    
    @Override
    public String getPrincipal() {
        return this.principal;
    }
    
    @Override
    public int getSecurityLevel() {
        return this.securityLevel;
    }
    
    @Override
    public int getSecurityModel() {
        return this.securityModel;
    }
    
    @Override
    public byte[] getContextName() {
        return this.contextName;
    }
    
    @Override
    public byte[] getAccessContextName() {
        return this.accessContextName;
    }
    
    @Override
    public final SnmpPdu getPdu() {
        return this.reqPdu;
    }
    
    @Override
    public final Enumeration<SnmpVarBind> getElements() {
        return this.varbinds.elements();
    }
    
    @Override
    public final Vector<SnmpVarBind> getSubList() {
        return this.varbinds;
    }
    
    @Override
    public final int getSize() {
        if (this.varbinds == null) {
            return 0;
        }
        return this.varbinds.size();
    }
    
    @Override
    public final int getVersion() {
        return this.version;
    }
    
    @Override
    public final int getRequestPduVersion() {
        return this.reqPdu.version;
    }
    
    @Override
    public final Object getUserData() {
        return this.data;
    }
    
    @Override
    public final int getVarIndex(SnmpVarBind o) {
        return this.varbinds.indexOf(o);
    }
    
    @Override
    public void addVarBind(SnmpVarBind obj) {
        this.varbinds.addElement(obj);
    }
    
    final void setRequestTree(SnmpRequestTree tree) {
        this.tree = tree;
    }
    
    final SnmpRequestTree getRequestTree() {
        return this.tree;
    }
    
    final Vector<SnmpVarBind> getVarbinds() {
        return this.varbinds;
    }
}
